ComPath Utils |build| |docs| |coverage|
=======================================
A repository containing abstract classes that all `Bio2BEL <https://github.com/bio2bel/>`_ packages should extend
in order to be adapted to the ComPath environment.

Installation |pypi_version| |python_versions| |pypi_license|
------------------------------------------------------------
``compath_utils`` can be installed easily from `PyPI <https://pypi.python.org/pypi/compath_utils>`_ with the
following code in your favorite terminal:

.. code-block:: sh

    $ python3 -m pip install compath_utils

or from the latest code on `GitHub <https://github.com/Compath/compath_utils>`_ with:

.. code-block:: sh

    $ python3 -m pip install git+https://github.com/ComPath/compath_utils.git@master


.. |build| image:: https://travis-ci.org/ComPath/ComPath-Utils.svg?branch=master
    :target: https://travis-ci.org/ComPath/ComPath-Utils
    :alt: Build Status

.. |docs| image:: http://readthedocs.org/projects/ComPath-Utils/badge/?version=latest
    :target: https://compath_utils.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |climate| image:: https://codeclimate.com/github/ComPath/ComPath-Utils/badges/gpa.svg
    :target: https://codeclimate.com/github/ComPath/ComPath-Utils
    :alt: Code Climate

.. |python_versions| image:: https://img.shields.io/pypi/pyversions/compath_utils.svg
    :alt: Stable Supported Python Versions

.. |pypi_version| image:: https://img.shields.io/pypi/v/compath_utils.svg
    :alt: Current version on PyPI

.. |pypi_license| image:: https://img.shields.io/pypi/l/compath_utils.svg
    :alt: MIT License

.. |coverage| image:: https://codecov.io/gh/ComPath/ComPath-Utils/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/ComPath/ComPath-Utils
